@@ -62,7 +62,6 @@ define ([
         // Employee actions
         //
 
-        // My profile
         target.push('myProfile', {
             'name': 'myProfile',
             'type': 'daction',
@@ -71,7 +70,6 @@ define ([
             'start': dactionStart('myProfile')
         });
 
-        // Employee profile Update
         target.push('empProfileUpdate', {
             'name': 'empProfileUpdate',
             'type': 'daction',
@@ -80,16 +78,22 @@ define ([
             'start': dactionStart('empProfileUpdate')
         }),
         
-        // New employee
         target.push('ldapLookupSubmit', {
             'name': 'ldapLookupSubmit',
             'type': 'daction',
             'menuText': 'Lookup',
-            'aclProfile': 'admin',
+            'aclProfile': 'passerby',
             'start': dactionStart('ldapLookupSubmit')
         }),
         
-        // Search employee
+        target.push('ldapSync', {
+            'name': 'ldapSync',
+            'type': 'daction',
+            'menuText': 'Sync',
+            'aclProfile': 'admin',
+            'start': dactionStart('ldapSync')
+        }),
+
         target.push('actionEmplSearch', {
             'name': 'actionEmplSearch',
             'type': 'daction',
@@ -98,7 +102,6 @@ define ([
             'start': dactionStart('actionEmplSearch')
         }),
         
-        // Masquerade as a different employee
         target.push('masqEmployee', {
             'name': 'masqEmployee',
             'type': 'daction',
