@@ -38,59 +38,18 @@
 
 define ([
     'lib',
+    'app/lib',
     'target'
 ], function (
     lib,
+    dochazkaLib,
     target
 ) {
 
     //
     // define dbrowser entries here
     //
-    var entries = {        
-
-        // Employee profile - nick
-        'ePnick': {
-            name: 'ePnick',
-            aclProfile: 'admin',
-            text: 'Nick',
-            prop: 'nick',
-            maxlen: 20
-        },
-        // Employee profile - EID
-        'ePeid': {
-            name: 'ePeid',
-            aclProfile: 'admin',
-            text: 'EID',
-            prop: 'eid',
-            maxlen: 8
-        },
-        // Employee profile - full name
-        'ePfullname': {
-            name: 'ePfullname',
-            aclProfile: 'admin',
-            text: 'Full name',
-            prop: 'fullname',
-            maxlen: 55
-        },
-        // Employee profile - email
-        'ePemail': {
-            name: 'ePemail',
-            aclProfile: 'admin',
-            text: 'Email',
-            prop: 'email',
-            maxlen: 55
-        },
-        // Employee profile - remark
-        'ePremark': {
-            name: 'ePremark',
-            aclProfile: 'admin',
-            text: 'Remark',
-            prop: 'remark',
-            maxlen: 55
-        },
-
-    };
+    var entries = dochazkaLib.entries;
     
     return function () {
         //
@@ -103,7 +62,8 @@ define ([
             'title': 'Employee search results',
             'preamble': null,
             'aclProfile': 'admin',
-            'entries': [ entries.ePnick, entries.ePeid, entries.ePfullname, entries.ePemail, entries.ePremark ],
+            'entries': [entries.ePnick, entries.ePsec_id, entries.ePfullname,
+                        entries.ePemail, entries.ePremark, entries.LDAPdochazka],
             'hook': lib.holdObject,
             'miniMenu': {
                 entries: ['masqEmployee'],
