@@ -38,11 +38,13 @@
 
 define ([
     'current-user',
+    'app/lib',
     'app/emp-lib',
     'app/prototypes',
     'target'
 ], function (
     currentUser,
+    lib,
     empLib,
     prototypes,
     target
@@ -51,119 +53,7 @@ define ([
     //
     // first, we define all entries
     //
-    var entries = {        
-
-        // Employee profile - nick
-        'ePnick': {
-            name: 'ePnick',
-            aclProfileRead: 'passerby',
-            aclProfileWrite: null,
-            text: 'Nick',
-            prop: 'nick',
-            maxlen: 20
-        },
-        // Employee profile - sec_id
-        'ePsec_id': {
-            name: 'ePsec_id',
-            aclProfileRead: 'passerby',
-            aclProfileWrite: null,
-            text: 'Workforce ID',
-            prop: 'sec_id',
-            maxlen: 8
-        },
-        // Employee profile - full name
-        'ePfullname': {
-            name: 'ePfullname',
-            aclProfileRead: 'passerby',
-            aclProfileWrite: 'active',
-            text: 'Full name',
-            prop: 'fullname',
-            maxlen: 55
-        },
-        // Employee profile - email
-        'ePemail': {
-            name: 'ePemail',
-            aclProfileRead: 'passerby',
-            aclProfileWrite: 'active',
-            text: 'Email',
-            prop: 'email',
-            maxlen: 55
-        },
-        // Employee profile - remark
-        'ePremark': {
-            name: 'ePremark',
-            aclProfileRead: 'admin',
-            aclProfileWrite: 'admin',
-            text: 'Remark',
-            prop: 'remark',
-            maxlen: 55
-        },
-        // Employee profile - status
-        'ePstatus': {
-            name: 'ePstatus',
-            aclProfileRead: 'inactive',
-            aclProfileWrite: 'admin',
-            text: 'Status',
-            prop: 'priv',
-            maxlen: 10
-        },
-        // Employee profile - statusSince
-        'ePstatusSince': {
-            name: 'ePstatusSince',
-            aclProfileRead: 'inactive',
-            aclProfileWrite: 'admin',
-            text: 'Since',
-            prop: 'effective',
-            maxlen: 30
-        },
-
-        // new employee - nick
-        'nEnick': {
-            name: 'nEnick',
-            aclProfileRead: null,
-            aclProfileWrite: 'admin',
-            text: 'Nick (*)',
-            prop: 'nick',
-            maxlen: 20
-        },
-        // new employee - full name
-        'nEfullname': {
-            name: 'nEfullname',
-            aclProfileRead: null,
-            aclProfileWrite: 'admin',
-            text: 'Full name',
-            prop: 'fullname',
-            maxlen: 55
-        },
-        // new employee - email
-        'nEemail': {
-            name: 'nEemail',
-            aclProfileRead: null,
-            aclProfileWrite: 'admin',
-            text: 'Email',
-            prop: 'email',
-            maxlen: 55
-        },
-        // new employee - remark
-        'nEremark': {
-            name: 'nEremark',
-            aclProfileRead: null,
-            aclProfileWrite: 'admin',
-            text: 'Remark',
-            prop: 'remark',
-            maxlen: 55
-        },
-    
-       // search employee - nick
-        'sEnick': {
-            name: 'sEnick',
-            aclProfileRead: null,
-            aclProfileWrite: 'admin',
-            text: 'Nick',
-            prop: 'searchKeyNick',
-            maxlen: 20
-        }
-    };
+    var entries = lib.entries;
     
     //
     // second, we define the dforms themselves
@@ -179,9 +69,9 @@ define ([
             'aclProfile': 'passerby',
             'entriesRead': [entries.ePfullname, entries.ePnick,
                 entries.ePsec_id, entries.ePemail, entries.ePremark,
-                entries.ePstatus, entries.ePstatusSince],
+                entries.ePpriv, entries.ePeffective],
             'entriesWrite': [],
-            'hook': empLib.getEmployeeObject,
+            'hook': empLib.getEmployeeProfile,
             'miniMenu': {
                 entries: ['empProfileEditRemark'],
                 back: ['Back', 'mainEmpl']
@@ -197,7 +87,7 @@ define ([
             'aclProfile': 'admin',
             'entriesRead': [entries.ePnick, entries.ePfullname],
             'entriesWrite': [entries.ePremark],
-            'hook': empLib.getEmployeeObject,
+            'hook': empLib.getEmployeeProfile,
             'miniMenu': {
                 entries: ['empProfileUpdate'],
                 back: ['Back', 'empProfile']
@@ -212,7 +102,7 @@ define ([
             'preamble': 'Enter employee nick for exact (case insensitive) match.',
             'aclProfile': 'active',
             'entriesRead': null,
-            'entriesWrite': [entries.nEnick],
+            'entriesWrite': [entries.ePnick],
             'hook': function () { return Object.create(prototypes.empProfile); },
             'miniMenu': {
                 entries: ['ldapLookupSubmit'],
@@ -220,19 +110,18 @@ define ([
             }
         });
 
-        target.push('ldapLookupDisplay', {
-            'name': 'ldapLookupDisplay',
+        target.push('ldapDisplayEmployee', {
+            'name': 'ldapDisplayEmployee',
             'type': 'dform',
-            'title': 'Employee profile',
-            'preamble': 'LDAP lookup success',
+            'title': 'LDAP employee record',
+            'preamble': null,
             'aclProfile': 'active',
             'entriesRead': [entries.ePfullname, entries.ePnick,
-                entries.ePsec_id, entries.ePemail, entries.ePremark,
-                entries.ePstatus, entries.ePstatusSince],
+                entries.ePsec_id, entries.ePemail, entries.LDAPdochazka],
             'entriesWrite': [],
-            'hook': empLib.getEmployeeObject,
+            'hook': empLib.getLdapEmployeeObject,
             'miniMenu': {
-                entries: ['masqEmployee'],
+                entries: ['ldapSync'],
                 back: ['Back', 'mainEmpl']
             }
         });
