@@ -50,15 +50,15 @@ define ([
             'menuText': 'Main menu',
             'title': 'Main menu',
             'aclProfile': 'passerby',
-            'entries': ['mainEmpl', 'mainPriv'],
+            'entries': ['mainEmpl', 'mainPriv', 'mainSched'],
             'back': 'logout'
         });
 
         target.push('mainEmpl', {
             'name': 'mainEmpl',
             'type': 'dmenu',
-            'menuText': 'Employee profile',
-            'title': 'Employee profile',
+            'menuText': 'Employee menu',
+            'title': 'Employee',
             'aclProfile': 'passerby',
             'entries': ['myProfile', 'ldapLookup', 'masqEmployee', 'searchEmployee'],
             'back': 'mainMenu'
@@ -67,13 +67,23 @@ define ([
         target.push('mainPriv', {
             'name': 'mainPriv',
             'type': 'dmenu',
-            'menuText': 'Privilege levels',
-            'title': 'Privilege levels',
+            'menuText': 'Priv (status) menu',
+            'title': 'Priv (status)',
             'aclProfile': 'passerby',
             'entries': ['privHistory'],
             'back': 'mainMenu'
         });
 
+        target.push('mainSched', {
+            'name': 'mainSched',
+            'type': 'dmenu',
+            'menuText': 'Schedule menu',
+            'title': 'Schedule',
+            'aclProfile': 'passerby',
+            'entries': [],
+            'back': 'mainMenu'
+        });
+
     };
 
 });
