@@ -55,15 +55,17 @@ define ([
 ) {
 
     var 
-        // employee object storage
-        employeeObject = Object.create(prototypes.empProfile),
+        employeeObject = Object.create(prototypes.empObject),
+        employeeProfile = Object.create(prototypes.empProfile),
+        ldapEmployeeObject = Object.create(prototypes.ldapEmpObject),
 
-        // method for accessing the stored employee object
         getEmployeeObject = function () { return employeeObject; },
+        getEmployeeProfile = function () { return employeeProfile; },
+        getLdapEmployeeObject = function () { return ldapEmployeeObject; },
 
         myProfile = function () {
             var cu = currentUser('obj');
-            if (employeeObject.effective !== null && employeeObject.nick === cu.nick) {
+            if (employeeProfile.effective !== null && employeeProfile.nick === cu.nick) {
                 target.pull('empProfile').start();
             } else {
                 loadEmpProfile(currentUser('obj').eid);
@@ -86,7 +88,7 @@ define ([
                             effective = st.payload.privhistory.effective
                             effective = effective.substr(0, effective.indexOf(" "));
                         }
-                        employeeObject = $.extend(
+                        employeeProfile = $.extend(
                             Object.create(prototypes.empProfile), {
                                 'eid': st.payload.emp.eid,
                                 'nick': st.payload.emp.nick,
@@ -98,7 +100,7 @@ define ([
                                 'effective': effective
                             }
                         );
-                        currentUser('obj', employeeObject);
+                        currentUser('obj', employeeProfile);
                         target.pull('empProfile').start();
                     }
                 },
@@ -106,10 +108,9 @@ define ([
             ajax(rest, sc, fc);
         },
 
-        // "search employee" method
-        searchEmp = function (obj) {
+        actionEmplSearch = function (obj) {
             // obj is searchKeyNick from the form
-            console.log("Entering target 'searchEmployee' start method with argument", obj);
+            console.log("Entering target 'actionEmplSearch' with argument", obj);
             var rest = {
                     "method": 'GET',
                     "path": 'employee/search/nick/' + encodeURIComponent(obj.searchKeyNick)
@@ -184,34 +185,102 @@ define ([
         },
 
         ldapLookupSubmit = function (emp) {
-            console.log("Entering function ldapLookupSubmit");
-            var rest = {
-                    method: 'PUT',
-                    // path: 'employee/nick/' + emp.nick || ''
+            console.log("Entering function ldapLookupSubmit, argument ->" + emp.nick + "<-");
+            // "nick" is the only property of emp that is populated
+            if (! emp.nick) {
+                return;
+            }
+            var nick = emp.nick,
+                rest = {
+                    method: 'GET',
+                    path: 'employee/nick/' + nick + "/ldap"
                 },
                 // success callback -- employee already exists
                 sc = function (st) {
-                    if (st.code === 'DOCHAZKA_CUD_OK') {
+                    if (st.code === 'DOCHAZKA_LDAP_LOOKUP') {
                         console.log("Payload is", st.payload);
-                        employeeObject = $.extend(employeeObject, st.payload);
-                        target.pull('ldapLookupDisplay').start();
+                        ldapEmployeeObject = $.extend(ldapEmployeeObject, st.payload);
                     }
+                    ldapEmployeeLink();
                 },
                 // failure callback -- employee doesn't exist
                 fc = function (st) {
-                    var err = st.payload.code;
-                    if (err === '404') {
-                        var msg = 'Employee ' + emp.nick + ' not found in LDAP';
-                        console.log(msg);
-                        $("#result").html(msg);
-                        $('input[name="sel"]').val('');
-                        $('input[name="entry0"]').focus();
+                    var msg = st.payload.message;
+                    console.log(msg);
+                    $("#result").html(msg);
+                    $('input[name="sel"]').val('');
+                    $('input[name="entry0"]').focus();
+                }
+            ajax(rest, sc, fc);
+        },
+
+        ldapEmployeeLink = function () {
+            // we assume the ldapEmployeeObject has already been 
+            // partially populated - we just need to determine whether
+            // or not the nick already exists in the local database
+            if (ldapEmployeeObject.nick === null) {
+                return ldapEmployeeObject;
+            }
+            ldapEmployeeObject.dochazka = false;
+            var rest = {
+                    "method": 'GET',
+                    "path": 'employee/nick/' + ldapEmployeeObject.nick
+                },
+                // success callback
+                sc = function (st) {
+                    if (st.code === "DISPATCH_EMPLOYEE_FOUND") {
+                        console.log("Payload is", st.payload);
+                        ldapEmployeeObject.dochazka = true;
+                    }
+                    if (document.getElementById('ldapLookup') ||
+                        document.getElementById('ldapDisplayEmployee')) {
+                        target.pull('ldapDisplayEmployee').start();
+                    }
+                },
+                fc = function (st) {
+                    if (document.getElementById('ldapLookup') ||
+                        document.getElementById('ldapDisplayEmployee')) {
+                        target.pull('ldapDisplayEmployee').start();
                     }
                 }
-            if (emp.hasOwnProperty('nick')) {
-                rest.path = 'employee/nick/' + emp.nick + '/ldap';
-                ajax(rest, sc, fc);
+            ajax(rest, sc, fc);
+        },
+
+        ldapSync = function (ldapEmp) {
+            console.log("Entered ldapSync with object", ldapEmp);
+            if (! ldapEmp.nick) {
+                return;
             }
+            var nick = ldapEmp.nick,
+                rest = {
+                    method: 'PUT',
+                    path: 'employee/nick/' + nick + '/ldap'
+                },
+                // success callback -- employee already exists
+                sc = function (st) {
+                    console.log("PUT ldap success, st object is", st);
+                    if (st.code === 'DOCHAZKA_CUD_OK') {
+                        console.log("Payload is", st.payload);
+                        ldapEmployeeObject = $.extend(ldapEmployeeObject, st.payload);
+                        ldapEmployeeObject.dochazka = true;
+                    }
+                    ldapEmployeeLink();
+                },
+                // failure callback -- employee doesn't exist
+                fc = function (st) {
+                    var err = st.payload.code,
+                        msg;
+                    if (err === '404') {
+                        msg = 'Employee ' + emp.nick + ' not found in LDAP';
+                    } else {
+                        msg = st.text;
+                    }
+                    console.log(msg);
+                    $("#result").html(msg);
+                    $('input[name="sel"]').val('');
+                    $('input[name="entry0"]').focus();
+                }
+            ajax(rest, sc, fc);
         },
 
 	// epuGen ("generate employee profile update function") is called to
@@ -230,14 +299,14 @@ define ([
                     "body": protoEmp.sanitize()
                 },
                 sc = function (st) {
-                    // st is 'Status'
+                    // st stands for "status", i.e. AJAX return value/object
                     if (afterTarget === 'empProfile') {
                         // this is an employee profile update
                         $("#result").html("Employee profile updated");
                     }
                     console.log("Saved new employee object to database: ", protoEmp);
-                    $.extend(employeeObject, st.payload);
-                    console.log("Profile object is", employeeObject);
+                    $.extend(employeeProfile, st.payload);
+                    console.log("Profile object is", employeeProfile);
                     target.pull(afterTarget).start();
                 },
                 fc = function (st) {
@@ -251,12 +320,15 @@ define ([
     // employee-related actions (see daction-start.js)
     return {
         getEmployeeObject: getEmployeeObject,
+        getEmployeeProfile: getEmployeeProfile,
+        getLdapEmployeeObject: getLdapEmployeeObject,
         mainEmpl: function (emp) { epuGen('mainEmpl', emp); },
         myProfile: myProfile,
         loadEmpProfile: loadEmpProfile,
         empProfileUpdate: function (emp) { epuGen('empProfile', emp); },
         ldapLookupSubmit: ldapLookupSubmit,
-        actionEmplSearch: searchEmp,
+        ldapSync: ldapSync,
+        actionEmplSearch: actionEmplSearch,
         endTheMasquerade: endTheMasquerade,
         masqEmployee: masqEmp
     };
